paulicirc.circuits
==================

.. automodule:: paulicirc.circuits

Circuit
-------

.. autoclass:: paulicirc.circuits.Circuit
    :show-inheritance:
    :members:
    :special-members: __new__, __getitem__, __setitem__

CircuitData
-----------

.. autodata:: paulicirc.circuits.CircuitData

CommutationCodeArray
--------------------

.. autodata:: paulicirc.circuits.CommutationCodeArray

PHASE_NBYTES
------------

.. autodata:: paulicirc.circuits.PHASE_NBYTES

commute
-------

.. autofunction:: paulicirc.circuits.commute
